<?php
/**
 * Plugin Name: WooCommerce Cancelled Order Email
 * Plugin URI: http://www.skyverge.com/blog/how-to-add-a-custom-woocommerce-email/
 * Description: Demo plugin for adding a custom WooCommerce email that sends a customer email when an order is cancelled
 * Author: SkyVerge
 * Author URI: http://www.skyverge.com
 * Version: 0.1
 *
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 *
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 *  Add a custom email to the list of emails WooCommerce should load
 *
 * @since 0.1
 * @param array $email_classes available email classes
 * @return array filtered available email classes
 */
function add_cancelled_order_woocommerce_email_class( $email_classes ) {

	// include our custom email class
	require( 'includes/class-wc-cancelled-order-email.php' );

	// add the email class to the list of email classes that WooCommerce loads
	$email_classes['WC_Cancelled_Order_Email'] = new WC_Cancelled_Order_Email();

	return $email_classes;

}
add_filter( 'woocommerce_email_classes', 'add_cancelled_order_woocommerce_email_class' );


/**
 * Register the cancelled email notification, which needs to be done prior to
 * the 'woocommerce_email_classes' action, which is called too late
 *
 * @since 0.1
 */
function register_woocommerce_cancelled_email_notification() {
	global $woocommerce;

	add_action( 'woocommerce_order_status_cancelled', array( $woocommerce, 'send_transactional_email') );
}

add_action( 'woocommerce_init', 'register_woocommerce_cancelled_email_notification' );
